@@ -18,7 +18,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.02';
+$VERSION = '0.05';
 
 bootstrap UUID $VERSION;
 
@@ -46,8 +46,16 @@ With these 3 routines UUID''s can easily be generated and parsed/un-parsed.
 
 UUID::{generate, parse, unparse}
 
+=head1 LICENSE
+
+This library is licensed under the Perl Artistic License. Details of this license can be found within the 'License' text file
+
 =head1 AUTHOR
 
+Joseph N. Hall <joseph.nathan.hall@gmail.com>
+
+Colin Faber <cfaber@clusterfs.com>
+
 Peter J. Braam <braam@mountainviewdata.com>
 
 =head1 SEE ALSO
